# 2022-03-14 Course JSC ISDL22

Course notes for JSC course 'Introduction to Scalable Deep Learning', 2022-04-05.

(PRACE training course, online).

[Homepage](https://www.fz-juelich.de/SharedDocs/Termine/IAS/JSC/EN/courses/2022/ptc-scalable-deep-learning-2022-1.html).

## Table of Contents

<!-- markdown-toc start - Don't edit this section. Run M-x markdown-toc-refresh-toc -->
**Table of Contents**

- [2022-03-14 Course JSC ISDL22](#2022-03-14-course-jsc-isdl22)
    - [Table of Contents](#table-of-contents)
    - [Day 1](#day-1)
        - [Tutorial 1.1 First Steps on the Supercomputer](#tutorial-11-first-steps-on-the-supercomputer)
            - [Exercise 1: SSH connection to Juwels](#exercise-1-ssh-connection-to-juwels)
                - [Login](#login)
                - [Tasks](#tasks)
            - [Exercise 2: Your first Slurm job](#exercise-2-your-first-slurm-job)
            - [Exercise 3 - Batch jobs](#exercise-3---batch-jobs)
        - [Tutorial 1.2 MPI](#tutorial-12-mpi)
    - [Day 2](#day-2)
        - [Tutorial 2.1 Deep learning recap](#tutorial-21-deep-learning-recap)
            - [Exercise 2.1.1 TFRecords](#exercise-211-tfrecords)
            - [Exercise 2.1.2](#exercise-212)
        - [Tutorial 2.2 First Horovod example](#tutorial-22-first-horovod-example)
    - [Day 3](#day-3)
    - [Day 4](#day-4)
    - [Day 5](#day-5)
    - [to_sort](#to_sort)
        - [general questions](#general-questions)

<!-- markdown-toc end -->

## Course resources

- [Course git repository - course material](https://gitlab.jsc.fz-juelich.de/MLDL_FZJ/juhaicu/jsc_public/sharedspace/teaching/intro_scalable_deep_learning/course-material)
[Course git repository - software environment](https://gitlab.jsc.fz-juelich.de/MLDL_FZJ/juhaicu/jsc_public/sharedspace/teaching/intro_scalable_deep_learning/software_environment)

## Day 1

### Tutorial 1.1 First Steps on the Supercomputer

#### Exercise 1: SSH connection to Juwels

JUWELS ssh key for ISDL22
Passphrase: chose officepw, generated file .ssh/id_ed25519.pub

``` bash
ssh-keygen -a 100 -t ed25519 -f ~/.ssh/id_ed25519
Generating public/private ed25519 key pair.
Enter passphrase (empty for no passphrase):
Enter same passphrase again:
Your identification has been saved in /home/johannes/.ssh/id_ed25519
Your public key has been saved in /home/johannes/.ssh/id_ed25519.pub
The key fingerprint is:
SHA256:9pr7tIghmg+amgzpUW/hV5wjalSjPLbRJobbwVDFRQE johannes@joe-9470m
The key's randomart image is:
+--[ED25519 256]--+
|     .oE++.      |
|    .  .         |
|   .   o         |
|    = + o .      |
|   o & +S=       |
| .. O X.o..      |
|o....O..  o      |
|++.+o..o = .     |
|*oo.. . =oo      |
+----[SHA256]-----+
```

Then went to https://judoor.fz-juelich.de/account/a/JSC_LDAP/wasmer1/system/juwels/add_ssh_key as instructed.

It showed me this (for my location OPH).

> To use our systems your public key options have to include a from=-clause to restrict the usage of the key to your personal IP address range.
> Your current IP address is 137.226.147.135. See the documentation for more information.
>
> Your public key and options string
> suggestion: from="137.226.147.135" ssh-ed25519 AAAAC3N...
>
> Additional public key options
> e.g. from="137.226.147.135",...

The content of file `id_ed25519.pub` is

```
ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIMyCekJPjTgHKcbQ/9IF813mbACylp0NlK3CrW60lSOq johannes@joe-9470m
```

So you can either upload the file (with from-clause added), or copy-paste the pub file content with from-clause added into the textbox.

So I copy-paste the following into the 'Your public key and options string' field.

```
from="137.226.147.135" ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIMyCekJPjTgHKcbQ/9IF813mbACylp0NlK3CrW60lSOq johannes@joe-9470m
```

Note that the Tutorial says this about for login from within FZJ. I haven't done that so far.

> Before you can add your public SSH key to the list of authorized SSH keys for Juwels, you must create a valid from-clause that meaningfully restricts the range of IPs. You have several options to that, e.g. check the IP range of your internet service provider (ISP). If you know the IP of your ISP, or if you can connect to a VPN giving you a fixed IP range (FZ Jülich's VPN is an example, but other institutions work as well), this is very easy. You can directly use the IP range as a from-clause. For FZ Jülich your from-clause would be:
>
> from="134.94.0.0/16"
>
> Note that the /16 indicates the subnet, hence all adresses of the form 134.94.*.* will be allowed. If you use this option, you can directly jump to the point Register your public key.

Note that I also haven't done the reverse DNS search as described in 'Register your public key.' with provider-based access, as I want to access not from all of OPH.

``` bash
nslookup 137.226.147.135
135.147.226.137.in-addr.arpa    name = keksnichtdose.oph.rwth-aachen.de.
```

which would lead to `from="*.oph.rwth-aachen.de" ssh-ed25519 AAAA`

##### Login

``` bash
ssh -i ~/.ssh/id_ed25519 wasmer1@juwels-booster.fz-juelich.de
```

##### Tasks

My project folder is `/p/project/training2207/wasmer1`.


source /p/project/training2207/software_environment/activate.sh

#### Exercise 2: Your first Slurm job

Start interactive session.

``` bash
(intro_scalable_dl_2022) [wasmer1@jwlogin21 wasmer1]$ srun --pty --nodes=1 -A training2207 --partition booster --gres gpu --time=00:15:00 /bin/bash
srun: job 5240279 queued and waiting for resources
srun: job 5240279 has been allocated resources
Setting HOROVOD_MPI_THREADS_DISABLE=1.
(intro_scalable_dl_2022) [wasmer1@jwb0074 wasmer1]$
```

Info on the GPU nodes.

``` bash
(intro_scalable_dl_2022) [wasmer1@jwb0074 wasmer1]$ nvidia-smi
Mon Mar 14 10:25:44 2022
+-----------------------------------------------------------------------------+
| NVIDIA-SMI 470.82.01    Driver Version: 470.82.01    CUDA Version: 11.4     |
|-------------------------------+----------------------+----------------------+
| GPU  Name        Persistence-M| Bus-Id        Disp.A | Volatile Uncorr. ECC |
| Fan  Temp  Perf  Pwr:Usage/Cap|         Memory-Usage | GPU-Util  Compute M. |
|                               |                      |               MIG M. |
|===============================+======================+======================|
|   0  NVIDIA A100-SXM...  On   | 00000000:03:00.0 Off |                    0 |
| N/A   43C    P0    57W / 400W |      0MiB / 40536MiB |      0%      Default |
|                               |                      |             Disabled |
+-------------------------------+----------------------+----------------------+
|   1  NVIDIA A100-SXM...  On   | 00000000:44:00.0 Off |                    0 |
| N/A   45C    P0    58W / 400W |      0MiB / 40536MiB |      0%      Default |
|                               |                      |             Disabled |
+-------------------------------+----------------------+----------------------+
|   2  NVIDIA A100-SXM...  On   | 00000000:84:00.0 Off |                    0 |
| N/A   44C    P0    53W / 400W |      0MiB / 40536MiB |      0%      Default |
|                               |                      |             Disabled |
+-------------------------------+----------------------+----------------------+
|   3  NVIDIA A100-SXM...  On   | 00000000:C4:00.0 Off |                    0 |
| N/A   45C    P0    56W / 400W |      0MiB / 40536MiB |      0%      Default |
|                               |                      |             Disabled |
+-------------------------------+----------------------+----------------------+

+-----------------------------------------------------------------------------+
| Processes:                                                                  |
|  GPU   GI   CI        PID   Type   Process name                  GPU Memory |
|        ID   ID                                                   Usage      |
|=============================================================================|
|  No running processes found                                                 |
+-----------------------------------------------------------------------------+
```

In a separate terminal, get info about the session.

``` bash
[wasmer1@jwlogin21 ~]$ squeue -u wasmer1
             JOBID PARTITION     NAME     USER ST       TIME  NODES NODELIST(REASON)
           5240279   booster     bash  wasmer1  R       0:39      1 jwb0074
```

1. What is the meaning of the string training2207 in the upper command?
  - `-A accountName`, refererence [slurm srun](https://slurm.schedmd.com/srun.html).
2. What is the partition and queue that your job was assigned to?
  - `booster`, queue: ???
3. What is your job's Slurm job ID?
  - `5240279`
4. Can you download a file from the internet from the compute node? Try for example wget https://gitlab.jsc.fz-juelich.de/MLDL_FZJ/juhaicu/jsc_public/sharedspace/teaching/intro_scalable_deep_learning/course-material/-/raw/main/README.md
  -
5. Cancel your job by using scancel <job_id>.

It did that automatically due to time limit.



Side note on access to JSC machines via vscode from Mehdi Cherti:
> @Sabrina just to be sure, you would like to edit the files on the supercomputer filesystem using visual studio locally ? if so, I would say one option would be to use sshfs , e.g., `sshfs login@juwels-booster.fz-juelich.de:<remote_folder> <your_local_directory>`

#### Exercise 3 - Batch jobs

- Modify the script such that it will print the host name of the compute node into a file hostname.txt.
  `echo `hostname` > output.txt`
- Add a line sleep 60 at the end of the script. Run the job again and use squeue to determine if and when the job is running. Hint: squeue -u $USER will only show your jobs.
- Cancel the job. (Take a look at the previous exercise if you cannot remember how to do this.)
- Use sacct -S 2020-01-01 to retrieve information about all jobs you have run since Jan 1st, 2020.

side note on `squeue` codes:
- https://curc.readthedocs.io/en/latest/running-jobs/squeue-status-codes.html

### Tutorial 1.2 MPI

side note:
For uploading data to JUWELS:
`rsync <local/path> <judoor-user>@juwels-booster.fz-juelich.de:/p/project/training2207/<judoor-user>/[...]`


## Day 2

### Tutorial 2.1 Deep learning recap

#### Exercise 2.1.1 TFRecords



#### Exercise 2.1.2

### Tutorial 2.2 First Horovod example


## Day 3

## Day 4

## Day 5

## to_sort

### general questions

eg at end of course

- Do, in your experience, JSC / HIDA clients use more tf or torch? application-dependent? Do you expect this to change?
- Which scientific fields by now actually use parallelized DL for their problems? Do you expect this to change?
- Is parallelization of classical ML models (like SVM) a thing for you?
