from ase import Atoms
from ase.build import bulk
import numpy as np

# Create a cubic structure (e.g., FCC Al)
al_fcc = bulk('Al', 'fcc', a=4.05)

print("Cell vectors:")
print(al_fcc.cell.array)

print("\nCell volume:")
print(al_fcc.get_volume())

# For a cubic system, we can calculate the lattice constant
lattice_constant = np.cbrt(al_fcc.get_volume())
print(f"\nCalculated lattice constant: {lattice_constant:.4f}")

# For non-cubic systems, you'd need to look at individual vector lengths
print("\nVector lengths:")
print(np.linalg.norm(al_fcc.cell.array, axis=1))

# You can also get cell lengths and angles
lengths = al_fcc.cell.lengths()
angles = al_fcc.cell.angles()
print("\nCell lengths:", lengths)
print("Cell angles:", angles)
