import numpy as np

def conventional_to_primitive_bcc(conventional_vectors):
    a1, a2, a3 = conventional_vectors
    p1 = 0.5 * (a1 - a2 + a3)
    p2 = 0.5 * (a1 + a2 - a3)
    p3 = 0.5 * (-a1 + a2 + a3)
    return np.array([p1, p2, p3])

def primitive_to_conventional_bcc(primitive_vectors):
    p1, p2, p3 = primitive_vectors
    a1 = p1 + p2 - p3
    a2 = -p1 + p2 + p3
    a3 = p1 - p2 + p3
    return np.array([a1, a2, a3])

# Example usage
conv_vectors = np.array([[3.0, 0, 0], [0, 3.0, 0], [0, 0, 3.0]])  # Example for a BCC metal like iron
prim_vectors = conventional_to_primitive_bcc(conv_vectors)
print("Primitive vectors:")
print(prim_vectors)

reconstructed_conv = primitive_to_conventional_bcc(prim_vectors)
print("\nReconstructed conventional vectors:")
print(reconstructed_conv)

print("\nCheck if reconstruction matches original:")
print(np.allclose(conv_vectors, reconstructed_conv))

# Additional check: Verify that the primitive cell volume is half the conventional cell volume
conv_volume = np.abs(np.linalg.det(conv_vectors))
prim_volume = np.abs(np.linalg.det(prim_vectors))
print(f"\nConventional cell volume: {conv_volume}")
print(f"Primitive cell volume: {prim_volume}")
print(f"Ratio (should be close to 2): {conv_volume / prim_volume}")
