import numpy as np

def conventional_to_primitive_fcc(conventional_vectors):
    a1, a2, a3 = conventional_vectors
    p1 = 0.5 * (a2 + a3)
    p2 = 0.5 * (a1 + a3)
    p3 = 0.5 * (a1 + a2)
    return np.array([p1, p2, p3])

def primitive_to_conventional_fcc(primitive_vectors):
    p1, p2, p3 = primitive_vectors
    a1 = -p1 + p2 + p3
    a2 = p1 - p2 + p3
    a3 = p1 + p2 - p3
    return np.array([a1, a2, a3])

# Example usage
conv_vectors = np.array([[3.6, 0, 0], [0, 3.6, 0], [0, 0, 3.6]])
prim_vectors = conventional_to_primitive_fcc(conv_vectors)
print("Primitive vectors:")
print(prim_vectors)

reconstructed_conv = primitive_to_conventional_fcc(prim_vectors)
print("\nReconstructed conventional vectors:")
print(reconstructed_conv)

print("\nCheck if reconstruction matches original:")
print(np.allclose(conv_vectors, reconstructed_conv))
