from ase import Atoms
from ase.data import atomic_numbers

def kkr_to_ase_atoms(params):
    # Get the lattice parameter
    alat = params.get_value('ALATBASIS')
    
    # Get the Bravais lattice vectors
    bravais = params.get_value('BRAVAIS')
    cell = [vec * alat for vec in bravais]
    
    # Get the number of atoms
    n_atoms = params.get_value('NAEZ')
    
    # Get the atomic positions
    positions = params.get_value('RBASIS')
    
    # Get the atomic numbers
    z_atoms = params.get_value('ZATOM')
    
    # Create a dictionary to convert atomic numbers to symbols
    atomic_number_symbol = {value: key for key, value in atomic_numbers.items()}
    
    # Convert atomic numbers to symbols
    symbols = [atomic_number_symbol[int(z)] for z in z_atoms]
    
    # Create the Atoms object
    atoms = Atoms(symbols=symbols,
                  scaled_positions=positions,
                  cell=cell,
                  pbc=True)
    
    return atoms

# Usage example
params = kkrparams()
params.read_keywords_from_inputcard('path/to/inputcard')
ase_atoms = kkr_to_ase_atoms(params)

# Print some information about the created Atoms object
print(f"Number of atoms: {len(ase_atoms)}")
print(f"Chemical formula: {ase_atoms.get_chemical_formula()}")
print(f"Cell vectors:\n{ase_atoms.get_cell()}")
print(f"Atomic positions:\n{ase_atoms.get_positions()}")
