import numpy as np
import matplotlib.pyplot as plt

def plot_comprehensive_potential_comparison(V1, V2, title1="Unvectorized", title2="Vectorized"):
    diff = np.abs(V1 - V2)
    
    # Create 2D slices through the center of the 3D arrays
    slice_xy_1 = V1[:, :, V1.shape[2]//2]
    slice_xz_1 = V1[:, V1.shape[1]//2, :]
    slice_yz_1 = V1[V1.shape[0]//2, :, :]
    
    slice_xy_2 = V2[:, :, V2.shape[2]//2]
    slice_xz_2 = V2[:, V2.shape[1]//2, :]
    slice_yz_2 = V2[V2.shape[0]//2, :, :]
    
    slice_xy_diff = diff[:, :, diff.shape[2]//2]
    slice_xz_diff = diff[:, diff.shape[1]//2, :]
    slice_yz_diff = diff[diff.shape[0]//2, :, :]
    
    fig, axes = plt.subplots(3, 3, figsize=(18, 18))
    
    # Function to plot a single slice
    def plot_slice(ax, data, title, is_diff=False):
        im = ax.imshow(data, cmap='viridis' if not is_diff else 'RdBu_r')
        ax.set_title(title)
        plt.colorbar(im, ax=ax)
    
    # Plot unvectorized slices
    plot_slice(axes[0, 0], slice_xy_1, f"{title1} XY Slice")
    plot_slice(axes[0, 1], slice_xz_1, f"{title1} XZ Slice")
    plot_slice(axes[0, 2], slice_yz_1, f"{title1} YZ Slice")
    
    # Plot vectorized slices
    plot_slice(axes[1, 0], slice_xy_2, f"{title2} XY Slice")
    plot_slice(axes[1, 1], slice_xz_2, f"{title2} XZ Slice")
    plot_slice(axes[1, 2], slice_yz_2, f"{title2} YZ Slice")
    
    # Plot difference slices
    plot_slice(axes[2, 0], slice_xy_diff, "Difference XY Slice", is_diff=True)
    plot_slice(axes[2, 1], slice_xz_diff, "Difference XZ Slice", is_diff=True)
    plot_slice(axes[2, 2], slice_yz_diff, "Difference YZ Slice", is_diff=True)
    
    plt.tight_layout()
    plt.show()

# Usage:
# plot_comprehensive_potential_comparison(V_p, V_p_v, "Unvectorized", "Vectorized")
