import matplotlib.pyplot as plt
import numpy as np
from ipywidgets import interact
from matplotlib.colors import TwoSlopeNorm

def create_interactive_contour_plot(cpot):
    # Calculate global min and max values
    vmin = np.min(cpot.grid.data)
    vmax = np.max(cpot.grid.data)
    
    # Create a symmetric range around zero
    abs_max = max(abs(vmin), abs(vmax))
    norm = TwoSlopeNorm(vmin=-abs_max, vcenter=0, vmax=abs_max)

    # Function to plot the contour at a given z-index
    def plot_contour(z_index):
        X = cpot.grid.meshgrids[0]
        Y = cpot.grid.meshgrids[1]
        V = cpot.grid.data
        
        fig, ax = plt.subplots(figsize=(10, 8))
        
        contour = ax.contourf(X[:, :, z_index], Y[:, :, z_index], V[:, :, z_index],
                              norm=norm, cmap='RdBu_r', levels=20)
        
        cbar = fig.colorbar(contour, ax=ax, extend='both')
        cbar.set_label('Value')
        
        ax.set_title(f'Contour plot at z_index={z_index}')
        ax.set_xlabel('X')
        ax.set_ylabel('Y')
        
        plt.show()

    # Interactive widget to choose z-index
    interact(plot_contour, z_index=(0, cpot.grid.data.shape[2]-1))
