from pymatgen.io.vasp import Chgcar
from pymatgen.core import Structure
import numpy as np

def write_chgcar_pymatgen(atoms, charge_density, filename='CHGCAR'):
    # Convert ASE Atoms to pymatgen Structure
    structure = Structure(
        lattice=atoms.get_cell(),
        species=atoms.get_chemical_symbols(),
        coords=atoms.get_positions(),
        coords_are_cartesian=True
    )
    
    # Create Chgcar object
    chgcar = Chgcar(structure, charge_density)
    
    # Write CHGCAR file
    chgcar.write_file(filename)

# Example usage:
# from ase import Atoms
# atoms = Atoms('H2O', positions=[[0, 0, 0], [0, 0, 1], [0, 1, 0]], cell=[5, 5, 5])
# charge_density = np.random.rand(50, 50, 50)
# write_chgcar_pymatgen(atoms, charge_density, 'CHGCAR')
