from git import Repo
from datetime import datetime

def get_commit_info():
    """
    Returns the current commit's short hash and formatted date.
    Must be run from within a git repository.
    
    Returns:
        tuple: (short_hash, formatted_date)
    """
    repo = Repo('.', search_parent_directories=True)
    commit = repo.head.commit
    
    # Get short hash (first 7 characters)
    short_hash = commit.hexsha[:7]
    
    # Get commit date and format it
    commit_date = datetime.fromtimestamp(commit.committed_date)
    formatted_date = commit_date.strftime('%Y-%m-%d-%H-%M-%S')
    
    return short_hash, formatted_date

# Example usage:
if __name__ == '__main__':
    try:
        hash_val, date_val = get_commit_info()
        print(f"Commit hash: {hash_val}")
        print(f"Commit date: {date_val}")
    except Exception as e:
        print(f"Error: {e}")
