from dataclasses import dataclass

@dataclass
class PlotFilePath:
    """Stores components for plot filepath generation.
    
    Valid values:
    notebook: 'ns', 'nc'
    potential: 'pi', 'pc', 'pd'
    trafo: 'cs', 'v2', 'v3', 'cwc'
    trafo_res: int (typically 60, 90, 120)
    plot_type: 
        - for ns: '2dcs', '3dvp'
        - for nc: '0cfzX', '0cizX', '0vp', '12dcs', '2svpm', '2ivsp', '2cpcp'
    """
    notebook: str
    potential: str
    trafo: str
    trafo_res: int
    plot_type: str
    commit_date: str
    commit_hash: str

    def to_filename(self) -> str:
        """Generate filename with components joined by dashes."""
        return "-".join([
            self.notebook,
            self.potential,
            self.trafo,
            str(self.trafo_res),
            self.plot_type,
            self.commit_date,
            self.commit_hash
        ])
    
    def __str__(self) -> str:
        return self.to_filename()
