from dataclasses import dataclass, field
from git_utils import git_commit_date, git_commit_hash  # Assuming these are your git functions

@dataclass
class PlotFilePath:
    """Stores components for plot filepath generation.
    
    Valid values:
    nb: 'ns', 'nc'
    pot: 'pi', 'pc', 'pd'
    trafo: 'cs', 'v2', 'v3', 'cwc'
    res: int (typically 60, 90, 120)
    type: 
        - for ns: '2dcs', '3dvp'
        - for nc: '0cfzX', '0cizX', '0vp', '12dcs', '2svpm', '2ivsp', '2cpcp'
    """
    nb: str
    pot: str
    trafo: str
    res: int
    type: str
    date: str = field(default_factory=git_commit_date)
    hash: str = field(default_factory=git_commit_hash)

    def to_filename(self) -> str:
        """Generate filename with components joined by dashes."""
        return "-".join([
            self.nb,
            self.pot,
            self.trafo,
            str(self.res),
            self.type,
            self.date,
            self.hash
        ])
    
    def __str__(self) -> str:
        return self.to_filename()
