#!/usr/bin/env python3
import os
import re
import sys
import argparse

def rename_files_and_folders(base_dir):
    # Rename directories first (bottom-up)
    for root, dirs, files in os.walk(base_dir, topdown=False):
        for name in dirs:
            old_path = os.path.join(root, name)
            new_name = name.replace(' ', '-')
            new_path = os.path.join(root, new_name)
            os.rename(old_path, new_path)
    
    # Then rename files
    for root, dirs, files in os.walk(base_dir):
        for name in files:
            old_path = os.path.join(root, name)
            new_name = name.replace(' ', '-')
            new_path = os.path.join(root, new_name)
            os.rename(old_path, new_path)

def update_org_links(base_dir):
    for root, dirs, files in os.walk(base_dir):
        for name in files:
            if name.endswith('.org'):
                file_path = os.path.join(root, name)
                with open(file_path, 'r') as f:
                    content = f.read()
                
                # Update links
                updated_content = re.sub(r'\[file:([^\]]+)\]', 
                                         lambda m: f'[file:{m.group(1).replace(" ", "-")}]', 
                                         content)
                
                if content != updated_content:
                    with open(file_path, 'w') as f:
                        f.write(updated_content)

def main():
    parser = argparse.ArgumentParser(description='Rename files/folders and update Org-mode links.')
    parser.add_argument('base_dir', help='Base directory containing Org-mode files and subfolders')
    args = parser.parse_args()

    base_dir = os.path.abspath(args.base_dir)

    if not os.path.isdir(base_dir):
        print(f"Error: {base_dir} is not a valid directory.")
        sys.exit(1)

    print(f"Processing directory: {base_dir}")

    # Task 1: Rename files and folders
    rename_files_and_folders(base_dir)
    
    # Task 2: Update Org-mode links
    update_org_links(base_dir)
    
    print("Renaming and updating completed successfully.")

if __name__ == "__main__":
    main()
