# Disclaimer

This document has been superseded by the [iffAiiDA user
documentation](https://iffmd.fz-juelich.de/QWgd6th7TrCKxd3PDgx2uQ#) and is
outdated. Kept around for archival purposes.

# iffaiida images documentation

## Description

Describes the software environments in each image, thematically sorted and
linked.

## Table of Contents

[TOC]

## Image inheritance

Each child extends the environment of its parent.

``` example
- iffaiida_base
  - template
    - aiida-v2
      - ml-base
        - ml-base-atomistic
        - ml-deep
        - ml-deep-atomistic
```

## Super images

*TODO split into separate documentations by super image.*

### Description

Super images. Set up AiiDA workflow engine and its atomistic simulation code plugins.

``` example
- iffaiida_base
  - template
    - aiida-v2
```

Image maintainer: Ingo Meyer.

Changelog:

*NA*

### Installed packages

- †: Installed by super image.
- †0: installed explicitly by base image.
- †1: installed explicitly by template image.
- †2: installed explicitly by next super image (=aiida-develop=)
- †2-: installed at least since here (from requirements files; might have been
  installed implicitly as dep of dep in a super image further up).
- †?: unsure where installed.

Ubuntu packages (OS / system).

- base image †0:
  - curl
  - emacs-nox
  - git
  - nano
  - nodejs
  - postgresql
  - python3
  - rabbitmqserver
  - rsync
  - screen
  - vim

Python packages.

- Python packages by type
  - 1) General Python (best-of-python)
    - Plotting & Visualization
      - [matplotlib](https://github.com/matplotlib/matplotlib) †2-. De facto standard Python plotting library.
      - [plotly](https://github.com/plotly/plotly.py) †1. Interactive plots.
      - [seaborn](https://github.com/mwaskom/seaborn) †2-. Better defaults for matplotlib.
    - Data Validation
      - [jsonschema](https://github.com/python-jsonschema/jsonschema) †2-. \"An implementation of the JSON Schema specification for Python\".
  - 2) General Python Code Development (best-of-python-dev)
    - Logging
      - [tqdm](https://github.com/tqdm/tqdm) †2-. \"A Fast, Extensible Progress Bar for Python and CLI\".
  - 3) General Jupyter (best-of-jupyter)
    - Interactive Widgets & Visualization
      - [ase-notebook](https://github.com/chrisjsewell/ase-notebook) †1. Jupyter viewer for `ase` atomic structures. Used by `aiida-kkr` for `aiida-core` versions \< 2.x.
      - [bqplot](https://github.com/bqplot/bqplot) †1. Simple interactive 2D plotting in Jupyter.
      - [ipywidgets](https://github.com/jupyter-widgets/ipywidgets) †2-. \"Interactive Widgets for the Jupyter Notebook\".
      - [nglview](https://github.com/nglviewer/nglview) †1. \"Jupyter widget to interactively view molecular structures and trajectories\".
      - [pythreejs](https://github.com/jupyter-widgets/pythreejs) †1. \"A Jupyter - Three.js bridge\".
    - JupyterLab Extensions
      - [nodejs](https://nodejs.org) †1. [Base dependency](https://jupyterlab.readthedocs.io/en/stable/user/extensions.html) for installing some JupyterLab extensions.
    - Notebook Sharing & Conversion
      - [nbconvert](https://github.com/jupyter/nbconvert) †2-. \"Jupyter Notebook Conversion\".
    - Notebook Tools
      - [nbformat](https://nbformat.readthedocs.io/en/latest/) †2-. Export notebooks to other formats.
  - 4) General Scientific Programming (best-of-scientific-programming)
    - Computational geometry
      - [pyhull](https://github.com/materialsvirtuallab/pyhull). \"For the computation of the convex hull, Delaunay triangulation and Voronoi diagram.\"
  - 5) General Machine Learning (best-of-ml-python)
    - Image Data
      - [pillow](https://github.com/python-pillow/Pillow) †2-. \"The friendly PIL fork (Python Imaging Library)\".
  - 6) General Atomistic Simulation (best-of-atomistic-simulation)
    - Crystallography
      - [spglib](https://spglib.github.io/spglib/). \"Spglib is a library for finding and handling crystal symmetries\".
    - Data Containers
      - [pycifrw](https://pypi.org/project/PyCifRW/). \"Python library for interacting with Crystallographic Information Framework (CIF) files.\"
    - Electronic Structure - Materials
      - [aiida-fleur/develop](https://github.com/JuDFTteam/aiida-fleur) †0. AiiDA plugin for FLEUR DFT code.
      - [aiida-iffdata](https://iffgit.fz-juelich.de/aiida/aiida_nodes) †1, aka `iffdata`.. Note: The is the CLI tool for loading iff AiiDA data nodes for iffaiida images. Not to be confused with the RDM CLI tool [iffdata](https://iffgit.fz-juelich.de/wortmann/iffdata).
      - [aiida-kkr/develop](https://github.com/JuDFTteam/aiida-kkr/tree/develop) †0. AiiDA plugin for JuKKR DFT codes.
      - [judft\_tutorials](https://github.com/JuDFTteam/judft_tutorials) †1. JuDFTteam tutorials.
      - [masci-tools/develop](https://github.com/JuDFTteam/masci-tools) †1. Base Python layer above the JuDFTteam simulation
        codes.
      - [pymatgen](https://github.com/materialsproject/pymatgen). \"Python Materials Genomics (pymatgen) is a robust materials analysis code that defines core object representations for structures and molecules with support for many electronic structure codes.\"
    - General Tools
      - [ase](https://wiki.fysik.dtu.dk/ase) †1. \"The Atomic Simulation Environment (ASE) is a set of tools and Python modules for setting up, manipulating, running, visualizing and analyzing atomistic simulations.\"
      - [mendeleev](https://github.com/lmmentel/mendeleev). Periodic table of elements for Python.
    - Scientific Workflows
      - [aiida-core](https://github.com/aiidateam/aiida-core) †0, aka `aiida`. AiiDA workflow engine.
  - Unsorted
    - [pandocfilters](https://github.com/jgm/pandocfilters) †2-. \"A python module for writing pandoc filters\".

## image ml-base

### Description

The most popular ML packages at your fingertips. Centered around scikit-learn. Neural networks are excluded. (All JAX-, PyTorch-, TensorFlow-dependent packages excluded.) All packages of parent image `aiida-v2`{.verbatim} included.

Image maintainer: Johannes Wasmer.

Changelog.

- 2022-11-17. v1.0 = list after first successful stable build (commit \"image ml-base, build test 20\").

### Installed packages

This list is a subset of the lists

- [Best-of lists](https://github.com/best-of-lists/best-of):
  - 1\) [best-of-python](https://github.com/ml-tooling/best-of-python)
  - 2\) [best-of-python-dev](https://github.com/ml-tooling/best-of-python-dev)
  - 3\) [best-of-jupyter](https://github.com/ml-tooling/best-of-jupyter)
- [wasmer\'s best-of lists](https://iffmd.fz-juelich.de/WxOZ75GTTHu2MNmnw2u5pA?view#Resources)
  - 4\) [best-of-scientific-programming](https://iffmd.fz-juelich.de/gxsOkPXATd-dR6r48ZFEiQ?view)
- [Best-of lists](https://github.com/best-of-lists/best-of):
  - 5\) [best-of-ml-python](https://github.com/ml-tooling/best-of-ml-python)
  - 5\) [general-machine-learning-resources](https://iffmd.fz-juelich.de/VkNGn9ziRPSbzx45SHTwEQ#)
- [wasmer\'s best-of lists](https://iffmd.fz-juelich.de/WxOZ75GTTHu2MNmnw2u5pA?view#Resources)
  - 6\) [best-of-atomistic-simulation](https://iffmd.fz-juelich.de/0-NbOz2yRqa1mvHD3RtTTQ#)
  - 7\) [best-of-atomistic-machine-learning](https://iffmd.fz-juelich.de/68Vn-YcuSWCun3bL_rJHXA?both#Models)

Only a selection of most popular packages of each subcategory in these lists are installed in the ml-base image.

Ubuntu packages (OS / system).

- Unsorted
  - [datalad](https://github.com/datalad/datalad). \"Keep code, data, containers under control with git and git-annex\".

Python packages.

pycaret\[full\] / ml-base, installed

- Python packages by type
  - 1) General Python (best-of-python)
    - Data Pipelines & Streaming
      - [joblib](https://github.com/joblib/joblib). \"Joblib: running Python functions as pipeline jobs\".
    - Data Serialization
      - [protobuf](https://github.com/protocolbuffers/protobuf). \"Protocol Buffers - Google\'s data interchange format\".
    - Data Validation
      - [pydantic](https://github.com/pydantic/pydantic). \"Data parsing and validation using Python type hints\".
    - Database Clients
      - [boto3](https://github.com/boto/boto3). \"AWS SDK for Python\".
    - Plotting & Visualization
      - [autoviz](https://github.com/AutoViML/AutoViz). \"Automatically Visualize any dataset, any size with a single line of code.\"
      - [bokeh](https://github.com/bokeh/bokeh). Interactive plots. (Standard plotter in `masci-tools`.)
      - [kaleido](https://github.com/plotly/Kaleido). \"Fast static image export for web-based visualization libraries\".
      - [pandas-profiling](https://github.com/ydataai/pandas-profiling). \"Create HTML profiling reports from pandas DataFrame objects\".
      - [plotly-resampler](https://github.com/predict-idlab/plotly-resampler). \"Visualize large time series data with plotly.py\".
  - 2) General Python Code Development (best-of-python-dev)
    - System Monitoring & Profiling
      - [psutil](https://github.com/giampaolo/psutil). \"Cross-platform lib for process and system monitoring in Python\".
  - 3) General Jupyter (best-of-jupyter)
    - Notebook Sharing & Conversion
      - [jupytext](https://github.com/mwouts/jupytext). Treat notebooks as script or text files. Good for clean notebook version control.
      - [nbdime](https://github.com/jupyter/nbdime). Cleaner notebook diffs.
  - 4) General Scientific Programming (best-of-scientific-programming)
    - Numerical Computing - General
      - [numba](https://github.com/numba/numba). \"NumPy aware dynamic Python compiler using LLVM\".
    - Parallel Computing - General
      - [fugue](https://github.com/fugue-project/fugue). \"A unified interface for distributed computing.\"
  - 5) General Machine Learning (best-of-ml-python)
    - Data Visualization
      - [umap-learn](https://github.com/lmcinnes/umap). \"Uniform Manifold Approximation and Projection\" (UMAP). Includes [densMAP](https://github.com/hhcho/densvis/tree/master/densmap).
      - [wordcloud](https://github.com/amueller/word_cloud) aka `word_cloud`. \"A little word cloud generator in Python\".
    - Image Data
      - [scikit-image](https://github.com/scikit-image/scikit-image). \"Image processing in Python\".
    - Hyperparameter Optimization & AutoML
      - [hyperopt](https://github.com/hyperopt/hyperopt). \"Distributed Asynchronous Hyperparameter Optimization in Python\".
      - [optuna](https://github.com/optuna/optuna). \"A hyperparameter optimization framework\".
      - [scikit-optimize](https://github.com/scikit-optimize/scikit-optimize). Sequential model-based optimization.
      - [tune](https://github.com/ray-project/ray/tree/master/python/ray/tune) aka ray tune. \"scalable \[distributed\] framework for hyperparameter search with a focus on deep learning and deep reinforcement learning.\"
      - [tune-sklearn](https://github.com/ray-project/tune-sklearn). \"A drop-in replacement for Scikit-Learn's GridSearchCV / RandomizedSearchCV\".
    - Machine Learning Frameworks
      - [catboost](https://github.com/catboost/catboost). Gradient boosting library.
      - [lightgbm](https://github.com/microsoft/LightGBM). Gradient boosting library. [Faster than XGBoost](https://neptune.ai/blog/xgboost-vs-lightgbm), as of 2022-07.
      - [scikit-learn](https://github.com/scikit-learn/scikit-learn). De facto standard Python ML package for shallow ML.
      - [statsmodels](https://github.com/statsmodels/statsmodels). \"statistical modeling and econometrics in Python\".
      - [xgboost](https://github.com/dmlc/xgboost). Gradient boosting framework.
    - Model Interpretability
      - [deepchecks](https://github.com/deepchecks/deepchecks). \"Tests for Continuous Validation of ML Models & Data.\"
      - [explainerdashboard](https://github.com/oegedijk/explainerdashboard). \"Quickly build Explainable AI dashboards\".
      - [fairlearn](https://github.com/fairlearn/fairlearn). \"assess and improve fairness of machine learning models.\"
      - [interpret](https://github.com/interpretml/interpret) aka Interpretml. \"Fit interpretable models. Explain blackbox machine learning.\"
      - [pyldavis](https://github.com/bmabey/pyLDAvis). \"Python library for interactive topic model visualization.\" #stale
      - [scikit-plot](https://github.com/reiinakano/scikit-plot). \"An intuitive library to add plotting functionality to scikit-learn objects.\" #stale
      - [shap](https://github.com/slundberg/shap). \"SHAP (SHapley Additive exPlanations) is a game theoretic approach to explain the output of any machine learning model.\"
      - [yellowbrick](https://github.com/DistrictDataLabs/yellowbrick). \"Visual analysis and diagnostic tools to facilitate machine learning model selection.\"
    - Model Serialization & Deployment
      - [mc2gen](https://github.com/BayesWitnesses/m2cgen). \"Transform ML models into a native code\".
    - Sklearn Utilities
      - scikit-learn-contrib (included if \> 1\'000 GitHub stars)
        - [category\_encoders](https://github.com/scikit-learn-contrib/category_encoders). sklearn compatible categorical variable encoders.
        - [imbalanced-learn](https://github.com/scikit-learn-contrib/imbalanced-learn). For imbalanced datasets.
      - Other sklearn utilities
        - [mlxtend](https://github.com/rasbt/mlxtend). \"A library of extension and helper modules for Python\'s data analysis and machine learning libraries.\"
        - [scikit-learn-intelex](https://github.com/intel/scikit-learn-intelex). Makes scikit-learn faster, CPU & GPU.
    - Text Data & NLP
      - [gensim](https://github.com/RaRe-Technologies/gensim). \"Topic Modelling for Humans\".
      - [nltk](https://github.com/nltk/nltk). \"Natural Language Toolkit (NLTK)\".
      - [spacy](https://github.com/explosion/spaCy). \"Industrial-strength Natural Language Processing (NLP) in
        Python\".
      - [textblob](https://github.com/sloria/TextBlob). \"Simple, Pythonic, text processing\". #stale
    - Time Series Data
      - [pmdarima](https://github.com/alkaline-ml/pmdarima). \"fill the void in Python\'s time series analysis capabilities\".
      - [sktime](https://github.com/sktime/sktime). \"A unified framework for machine learning with time series\".
      - [statsforecast](https://github.com/Nixtla/statsforecast). \"Lightning fast forecasting with statistical and econometric models.\"
      - [tbats](https://github.com/intive-DataScience/tbats). \"BATS and TBATS forecasting methods\".
    - Workflow & Experiment Tracking, MLOps
      - [mlflow](https://github.com/mlflow/mlflow). MLflow is a platform to streamline machine learning development, including tracking experiments, packaging code into reproducible runs, and sharing and deploying models.
      - [pycaret](https://github.com/pycaret/pycaret). \"PyCaret is an open-source, low-code machine learning library in Python that automates machine learning workflows.\" Wraps many popular ML packages.
    - Unsorted
      - [evidently](https://github.com/evidentlyai/evidently). \"Evaluate and monitor ML models from validation to production.\"
      - [gradio](https://github.com/gradio-app/gradio). \"Create UIs for your machine learning model in Python in 3 minutes\".
      - [kmodes](https://github.com/nicodv/kmodes). \"k-modes and k-prototypes clustering algorithms, for clustering categorical data\".
      - [pyod](https://github.com/yzhao062/pyod) aka PyOD. \"A Comprehensive and Scalable Python Library for Outlier Detection (Anomaly Detection)\".

### Not installed

Reasons: Dependency conflict, or addition candidate.

If you want to use some of these packages, ask image maintainer to include them. Alternitavely, `git clone` the package and [import it locally](https://www.google.com/search?&q=python+include+package+locally+without+install).

*TODO separate problematic from candidates.*

- Python packages by type
  - 1) General Python (best-of-python)
    - Data Pipelines & Streaming
      - [great\_expectations](https://github.com/great-expectations/great_expectations). Testing and documentation framework for data pipelines.
      - [kedro](https://github.com/kedro-org/kedro). \"A Python framework for creating reproducible, maintainable and modular data science code.\"
      - [ploomber](https://github.com/ploomber/ploomber). \"Ploomber is the fastest way to build data pipelines\". Auto-refactor legacy notebooks into pipelines. SLURM support.
    - System Monitoring & Profiling
      - [perfplot](https://github.com/nschloe/perfplot). \"Performance analysis for Python snippets\"
  - 3) General Jupyter (best-of-jupyter)
    - JupyterLab Extensions
      - [jupyterlab-variableinspector](https://github.com/lckr/jupyterlab-variableInspector) aka `lckr-jupyterlab-variableinspector`. Live variable inspection sideview in Jupyter.
  - 4) General Scientific Programming (best-of-scientific-programming)
    - Metaheuristics
      - [scikit-opt](https://github.com/guofei9987/scikit-opt). \"Powerful Python module for Heuristic Algorithms\".
  - 5) General Machine Learning (best-of-ml-python)
    - Hyperparameter Optimization & AutoML
      - [auto-sklearn](https://github.com/automl/auto-sklearn). AutoML with scikit-learn.
      - [bayesian-optimization](https://github.com/fmfn/BayesianOptimization). Global optimization with gaussian processes.
      - [hyperopt-sklearn](https://github.com/hyperopt/hyperopt-sklearn) aka `hpsklearn`. \"Hyper-parameter optimization for sklearn\" based on `hyperopt`.
    - Machine Learning Frameworks
      - [numpy-ml](https://github.com/ddbourgin/numpy-ml). \"Machine learning, in numpy\".
    - Model Serialization & Deployment
      - [onnx](https://github.com/onnx/onnx). \"Open standard for machine learning interoperability\".
      - [skl2onnx](https://github.com/onnx/sklearn-onnx) aka sklearn-onnx. \"Convert scikit-learn models and pipelines to ONNX\".
      - [onnxmltools](https://github.com/onnx/onnxmltools). Convert LightGBM, XGBoost etc. to ONNX.
    - Probabilistics & Statistics
      - [gpy](https://github.com/SheffieldML/GPy) aka GPy. \"Gaussian processes framework in python\".
      - [pymc](https://github.com/pymc-devs/pymc) aka PyMC3.
    - Reinforcement Learning
      - [gym](https://github.com/openai/gym). \"A toolkit for developing and comparing reinforcement learning algorithms.\"
    - Sklearn Utilities
      - scikit-learn-contrib (included if \> 1\'000 GitHub stars)
        - [hdbscan](https://github.com/scikit-learn-contrib/hdbscan). Hierarchical Density-Based Spatial Clustering of Applications with Noise. HDBSCAN has largely replaced k-means as first clustering to try.
        - [metric-learn](https://github.com/scikit-learn-contrib/metric-learn). Metric learning algorithms.
        - [sklearn-contrib-lightning](https://github.com/scikit-learn-contrib/lightning). Large-scale linear classification, regression and ranking.
        - [sklearn-pandas](https://github.com/scikit-learn-contrib/sklearn-pandas). Pandas integration with sklearn.
    - Workflow & Experiment Tracking, MLOps
      - [dvc](https://github.com/iterative/dvc). Data Version Control (DVC) is a \"Open-source Version Control System for Machine Learning Projects\".
      - [cml](https://github.com/iterative/cml). Continuous Machine Learning (CML) is \"CI/CD for Machine Learning Projects\". Use GitLab or GitHub to manage ML experiments.
      - [mlem](https://github.com/iterative/mlem/). \"Open-source tool to simplify ML model deployment\". Capture ML model metadata automatically, use Git as model registry.

## image ml-base-atomistic

The most popular atomistic ML (AML) packages at your fingertips. Neural network AML excluded. This means that this image is focused on representation engineering. All packages of parent image `ml-base`{.verbatim} included.

Image maintainer: Johannes Wasmer.

Changelog.

v1.0 = list after first successful stable build (image ml-base-atomistic, build test 06).

### Installed packages

This list is a subset of the lists

- [Best-of lists](https://github.com/best-of-lists/best-of):
  - 5\) [best-of-ml-python](https://github.com/ml-tooling/best-of-ml-python)
  - 5\) [general-machine-learning-resources](https://iffmd.fz-juelich.de/VkNGn9ziRPSbzx45SHTwEQ#)
- [wasmer\'s best-of lists](https://iffmd.fz-juelich.de/WxOZ75GTTHu2MNmnw2u5pA?view#Resources)
  - 6\) [best-of-atomistic-simulation](https://iffmd.fz-juelich.de/0-NbOz2yRqa1mvHD3RtTTQ#)
  - 7\) [best-of-atomistic-machine-learning](https://iffmd.fz-juelich.de/68Vn-YcuSWCun3bL_rJHXA?both#Models)

Ubuntu packages (OS / system).

*none*

Python packages.

- Python packages by type
  - 5) General Machine Learning (best-of-ml-python) - Probabilistics & Statistics
    - [gpy](https://github.com/SheffieldML/GPy) aka GPy. \"Gaussian processes framework in python\".
  - 6) General Atomistic Simulation (best-of-atomistic-simulation)
    - Electronic Structure - General
      - [pyscf](https://github.com/pyscf/pyscf/). \"Open-source collection of electronic structure modules powered by Python\". Integrated with ASE.
    - Scientific Workflows
      - [aiida-jutools](https://github.com/JuDFTteam/aiida-jutools/tree/develop). Base AiiDA layer above JuDFTteam simulation codes.
  - 7) General Atomistic Machine Learning (best-of-atomistic-machine-learning)
    - General Tools
      - [amp-atomistics](https://bitbucket.org/andrewpeterson/amp). Amp: Atomistic Machine-learning Package. ASE calculator for atomistic machine learning, with descriptors and models.
      - [jarvis-tools](https://github.com/usnistgov/jarvis). JARVIS. \"An open-source software package for data-driven atomistic materials design\".
      - [mastml](https://github.com/uw-cmg/MAST-ML) aka MAST-ML. \"The Materials Simulation Toolkit for Machine Learning. An automated open source toolkit to accelerate data-driven materials research.\" Tools for the whole AML pipeline.
      - [skcosmo](https://github.com/lab-cosmo/scikit-cosmo) aka scikit-cosmo. Extension to scikit-learn used in the atomistic machine learning methods by cosmo-lab. Various regression models, feature and sample selection methods.
    - Representation engineering - General
      - [matminer](https://github.com/hackingmaterials/automatminer). \"Data mining for materials science\". Descriptors, data retrievers for popular materials databases.
    - Representation engineering - Structural Descriptors
      - [chemenv](https://jageo.github.io/jekyll/update/2018/03/01/ChemEnv-Tutorial-online.html). ChemEnv: a fast and robust coordination environment identification tool. [Included](https://github.com/materialsproject/pymatgen/tree/master/pymatgen/analysis/chemenv) in `pymatgen`.
      - [dscribe](https://github.com/SINGROUP/dscribe). Structural descriptors (SOAP etc).
      - [librascal](https://github.com/lab-cosmo/librascal). Structural descriptors (SOAP etc).
      - [nice](https://github.com/lab-cosmo/nice). Dimensionality reduction while preserving information content tool for structural representations.
    - Representation engineering - Structural Models
      - [boss](https://gitlab.com/cest-group/boss) aka `aalto-boss`. \"Bayesian Optimization Structure Search (BOSS) is an active machine learning technique for accelerated global exploration of energy and property phase space.\" Includes Gaussian Process Regression (GPR).
      - [ml-dft](https://github.com/MihailBogojeski/ml-dft). \"A package for density functional approximation using machine learning.\"
      - [quip and quippy](https://github.com/libAtoms/QUIP) aka `quippy-ase`. Collection of machine-learning interatomic potentials. Includes the Gaussian Approximation Potential.
      - [tensoap](https://github.com/dilkins/TENSOAP) aka `sagpr`, SA-GPR, SOAPFAST. Symmetry-Adapted Gaussian Process Regression (SA-GPR). (Note: Compiling Long-range descriptors LODE need Fortran compiler. Not installed for now.)
      - [salted](https://github.com/andreagrisafi/SALTED). Symmetry-Adapted Learning of Three-dimensional Electron Densities.
    - Unsupervised learning
      - [dadapy](https://github.com/sissa-data-science/DADApy). \"Distance-based Analysis of DAta-manifolds in python\".

### Not installed packages

Reasons: Dependency conflict, or addition candidate.

If you want to use some of these packages, ask image maintainer to include them. Alternitavely, `git clone` the package and [import it locally](https://www.google.com/search?&q=python+include+package+locally+without+install).

*TODO separate problematic from candidates.*

- Python packages by type
  - 7) General Atomistic Machine Learning (best-of-atomistic-machine-learning)
    - General Tools
      - [automatminer](https://github.com/hackingmaterials/automatminer). \"An automatic engine for predicting materials properties.\"
      - [cmlkit](https://github.com/sirmarcel/cmlkit). Structural descriptors (SOAP), linear models (KRR).
      - [maml](https://github.com/materialsvirtuallab/maml). \"Python for Materials Machine Learning\". Descriptors, models. By materialsvirtuallab.
    - Representation engineering - Structural Descriptors
      - [kqeq](https://gitlab.com/jmargraf/kqeq). \"Allows training and using physics-based machine-learning models for predicting charge distributions in molecules and materials.\"
      - ([rascaline](https://github.com/Luthaf/rascaline). Structural descriptors (SOAP etc). *Not yet installed*.)
    - Representation engineering - Structural Models
      - [flare](https://github.com/mir-group/flare) aka `mir-flare`. \"An open-source Python package for creating fast and accurate interatomic potentials.\"

also missed:

- DeePKS-kit
- ASAPlib

## image ml-deep

### Description

The most popular neural network ML packages at your fingertips. Centered around JAX, PyTorch, TensorFlow. All packages of parent image `ml-base-atomistic`{.verbatim} included. Note: iffaiida has no GPUs. So only the CPU-versions of these NN packages are installed. But you can connect to a cluster and run on the GPUs there.

Image maintainer: Johannes Wasmer.

Changelog.

- *Under construction.*

## image ml-deep-atomistic

### Description

The most popular neural network atomistic ML (AML) packages at your fingertips. This means that this image is focused on representation learning. All packages of parent image `ml-deep`{.verbatim} included.

Image maintainer: Johannes Wasmer.

Changelog.

- *Under construction.*
